@@ -62,7 +62,9 @@ sub copy {
 
     if (defined &syscopy && \&syscopy != \&copy
 	&& !$to_a_handle
-	&& !($from_a_handle && $^O eq 'os2'))	# OS/2 cannot handle handles
+	&& !($from_a_handle && $^O eq 'os2' )	# OS/2 cannot handle handles
+	&& !($from_a_handle && $^O eq 'mpeix')	# and neither can MPE/iX.
+       )	
     {
 	return syscopy($from, $to);
     }
@@ -174,7 +176,20 @@ sub move {
 *mv = \&move;
 
 # &syscopy is an XSUB under OS/2
-*syscopy = ($^O eq 'VMS' ? \&rmscopy : \&copy) unless defined &syscopy;
+unless (defined &syscopy) {
+    if ($^O eq 'VMS') {
+	*syscopy = \&rmscopy;
+    } elsif ($^O eq 'mpeix') {
+	*syscopy = sub {
+	    return 0 unless @_ == 0;
+	    # Use the MPE cp program in order to
+	    # preserve MPE file attributes.
+	    return system('/bin/cp', '-f', $_[0], $_[1]) == 0;
+	};
+    } else {
+	*syscopy = \&copy;
+    }
+}
 
 1;
 
