@@ -735,8 +735,8 @@ malloc(register size_t nbytes)
 			      (long)size));
 
 	/* remove from linked list */
-#if defined(RCHECK) && !defined(USE_PERL_SBRK)
-	if (*((int*)p) & (sizeof(union overhead) - 1))
+#if defined(RCHECK)
+	if (((UV)p) & (MEM_ALIGNBYTES - 1))
 	    PerlIO_printf(PerlIO_stderr(), "Corrupt malloc ptr 0x%lx at 0x%lx\n",
 		(unsigned long)*((int*)p),(unsigned long)p);
 #endif
