@@ -36,325 +36,326 @@ typedef enum {
 	OP_REGCRESET,	/* 29 */
 	OP_REGCOMP,	/* 30 */
 	OP_MATCH,	/* 31 */
-	OP_SUBST,	/* 32 */
-	OP_SUBSTCONT,	/* 33 */
-	OP_TRANS,	/* 34 */
-	OP_SASSIGN,	/* 35 */
-	OP_AASSIGN,	/* 36 */
-	OP_CHOP,	/* 37 */
-	OP_SCHOP,	/* 38 */
-	OP_CHOMP,	/* 39 */
-	OP_SCHOMP,	/* 40 */
-	OP_DEFINED,	/* 41 */
-	OP_UNDEF,	/* 42 */
-	OP_STUDY,	/* 43 */
-	OP_POS,		/* 44 */
-	OP_PREINC,	/* 45 */
-	OP_I_PREINC,	/* 46 */
-	OP_PREDEC,	/* 47 */
-	OP_I_PREDEC,	/* 48 */
-	OP_POSTINC,	/* 49 */
-	OP_I_POSTINC,	/* 50 */
-	OP_POSTDEC,	/* 51 */
-	OP_I_POSTDEC,	/* 52 */
-	OP_POW,		/* 53 */
-	OP_MULTIPLY,	/* 54 */
-	OP_I_MULTIPLY,	/* 55 */
-	OP_DIVIDE,	/* 56 */
-	OP_I_DIVIDE,	/* 57 */
-	OP_MODULO,	/* 58 */
-	OP_I_MODULO,	/* 59 */
-	OP_REPEAT,	/* 60 */
-	OP_ADD,		/* 61 */
-	OP_I_ADD,	/* 62 */
-	OP_SUBTRACT,	/* 63 */
-	OP_I_SUBTRACT,	/* 64 */
-	OP_CONCAT,	/* 65 */
-	OP_STRINGIFY,	/* 66 */
-	OP_LEFT_SHIFT,	/* 67 */
-	OP_RIGHT_SHIFT,	/* 68 */
-	OP_LT,		/* 69 */
-	OP_I_LT,	/* 70 */
-	OP_GT,		/* 71 */
-	OP_I_GT,	/* 72 */
-	OP_LE,		/* 73 */
-	OP_I_LE,	/* 74 */
-	OP_GE,		/* 75 */
-	OP_I_GE,	/* 76 */
-	OP_EQ,		/* 77 */
-	OP_I_EQ,	/* 78 */
-	OP_NE,		/* 79 */
-	OP_I_NE,	/* 80 */
-	OP_NCMP,	/* 81 */
-	OP_I_NCMP,	/* 82 */
-	OP_SLT,		/* 83 */
-	OP_SGT,		/* 84 */
-	OP_SLE,		/* 85 */
-	OP_SGE,		/* 86 */
-	OP_SEQ,		/* 87 */
-	OP_SNE,		/* 88 */
-	OP_SCMP,	/* 89 */
-	OP_BIT_AND,	/* 90 */
-	OP_BIT_XOR,	/* 91 */
-	OP_BIT_OR,	/* 92 */
-	OP_NEGATE,	/* 93 */
-	OP_I_NEGATE,	/* 94 */
-	OP_NOT,		/* 95 */
-	OP_COMPLEMENT,	/* 96 */
-	OP_ATAN2,	/* 97 */
-	OP_SIN,		/* 98 */
-	OP_COS,		/* 99 */
-	OP_RAND,	/* 100 */
-	OP_SRAND,	/* 101 */
-	OP_EXP,		/* 102 */
-	OP_LOG,		/* 103 */
-	OP_SQRT,	/* 104 */
-	OP_INT,		/* 105 */
-	OP_HEX,		/* 106 */
-	OP_OCT,		/* 107 */
-	OP_ABS,		/* 108 */
-	OP_LENGTH,	/* 109 */
-	OP_SUBSTR,	/* 110 */
-	OP_VEC,		/* 111 */
-	OP_INDEX,	/* 112 */
-	OP_RINDEX,	/* 113 */
-	OP_SPRINTF,	/* 114 */
-	OP_FORMLINE,	/* 115 */
-	OP_ORD,		/* 116 */
-	OP_CHR,		/* 117 */
-	OP_CRYPT,	/* 118 */
-	OP_UCFIRST,	/* 119 */
-	OP_LCFIRST,	/* 120 */
-	OP_UC,		/* 121 */
-	OP_LC,		/* 122 */
-	OP_QUOTEMETA,	/* 123 */
-	OP_RV2AV,	/* 124 */
-	OP_AELEMFAST,	/* 125 */
-	OP_AELEM,	/* 126 */
-	OP_ASLICE,	/* 127 */
-	OP_EACH,	/* 128 */
-	OP_VALUES,	/* 129 */
-	OP_KEYS,	/* 130 */
-	OP_DELETE,	/* 131 */
-	OP_EXISTS,	/* 132 */
-	OP_RV2HV,	/* 133 */
-	OP_HELEM,	/* 134 */
-	OP_HSLICE,	/* 135 */
-	OP_UNPACK,	/* 136 */
-	OP_PACK,	/* 137 */
-	OP_SPLIT,	/* 138 */
-	OP_JOIN,	/* 139 */
-	OP_LIST,	/* 140 */
-	OP_LSLICE,	/* 141 */
-	OP_ANONLIST,	/* 142 */
-	OP_ANONHASH,	/* 143 */
-	OP_SPLICE,	/* 144 */
-	OP_PUSH,	/* 145 */
-	OP_POP,		/* 146 */
-	OP_SHIFT,	/* 147 */
-	OP_UNSHIFT,	/* 148 */
-	OP_SORT,	/* 149 */
-	OP_REVERSE,	/* 150 */
-	OP_GREPSTART,	/* 151 */
-	OP_GREPWHILE,	/* 152 */
-	OP_MAPSTART,	/* 153 */
-	OP_MAPWHILE,	/* 154 */
-	OP_RANGE,	/* 155 */
-	OP_FLIP,	/* 156 */
-	OP_FLOP,	/* 157 */
-	OP_AND,		/* 158 */
-	OP_OR,		/* 159 */
-	OP_XOR,		/* 160 */
-	OP_COND_EXPR,	/* 161 */
-	OP_ANDASSIGN,	/* 162 */
-	OP_ORASSIGN,	/* 163 */
-	OP_METHOD,	/* 164 */
-	OP_ENTERSUB,	/* 165 */
-	OP_LEAVESUB,	/* 166 */
-	OP_CALLER,	/* 167 */
-	OP_WARN,	/* 168 */
-	OP_DIE,		/* 169 */
-	OP_RESET,	/* 170 */
-	OP_LINESEQ,	/* 171 */
-	OP_NEXTSTATE,	/* 172 */
-	OP_DBSTATE,	/* 173 */
-	OP_UNSTACK,	/* 174 */
-	OP_ENTER,	/* 175 */
-	OP_LEAVE,	/* 176 */
-	OP_SCOPE,	/* 177 */
-	OP_ENTERITER,	/* 178 */
-	OP_ITER,	/* 179 */
-	OP_ENTERLOOP,	/* 180 */
-	OP_LEAVELOOP,	/* 181 */
-	OP_RETURN,	/* 182 */
-	OP_LAST,	/* 183 */
-	OP_NEXT,	/* 184 */
-	OP_REDO,	/* 185 */
-	OP_DUMP,	/* 186 */
-	OP_GOTO,	/* 187 */
-	OP_EXIT,	/* 188 */
-	OP_OPEN,	/* 189 */
-	OP_CLOSE,	/* 190 */
-	OP_PIPE_OP,	/* 191 */
-	OP_FILENO,	/* 192 */
-	OP_UMASK,	/* 193 */
-	OP_BINMODE,	/* 194 */
-	OP_TIE,		/* 195 */
-	OP_UNTIE,	/* 196 */
-	OP_TIED,	/* 197 */
-	OP_DBMOPEN,	/* 198 */
-	OP_DBMCLOSE,	/* 199 */
-	OP_SSELECT,	/* 200 */
-	OP_SELECT,	/* 201 */
-	OP_GETC,	/* 202 */
-	OP_READ,	/* 203 */
-	OP_ENTERWRITE,	/* 204 */
-	OP_LEAVEWRITE,	/* 205 */
-	OP_PRTF,	/* 206 */
-	OP_PRINT,	/* 207 */
-	OP_SYSOPEN,	/* 208 */
-	OP_SYSSEEK,	/* 209 */
-	OP_SYSREAD,	/* 210 */
-	OP_SYSWRITE,	/* 211 */
-	OP_SEND,	/* 212 */
-	OP_RECV,	/* 213 */
-	OP_EOF,		/* 214 */
-	OP_TELL,	/* 215 */
-	OP_SEEK,	/* 216 */
-	OP_TRUNCATE,	/* 217 */
-	OP_FCNTL,	/* 218 */
-	OP_IOCTL,	/* 219 */
-	OP_FLOCK,	/* 220 */
-	OP_SOCKET,	/* 221 */
-	OP_SOCKPAIR,	/* 222 */
-	OP_BIND,	/* 223 */
-	OP_CONNECT,	/* 224 */
-	OP_LISTEN,	/* 225 */
-	OP_ACCEPT,	/* 226 */
-	OP_SHUTDOWN,	/* 227 */
-	OP_GSOCKOPT,	/* 228 */
-	OP_SSOCKOPT,	/* 229 */
-	OP_GETSOCKNAME,	/* 230 */
-	OP_GETPEERNAME,	/* 231 */
-	OP_LSTAT,	/* 232 */
-	OP_STAT,	/* 233 */
-	OP_FTRREAD,	/* 234 */
-	OP_FTRWRITE,	/* 235 */
-	OP_FTREXEC,	/* 236 */
-	OP_FTEREAD,	/* 237 */
-	OP_FTEWRITE,	/* 238 */
-	OP_FTEEXEC,	/* 239 */
-	OP_FTIS,	/* 240 */
-	OP_FTEOWNED,	/* 241 */
-	OP_FTROWNED,	/* 242 */
-	OP_FTZERO,	/* 243 */
-	OP_FTSIZE,	/* 244 */
-	OP_FTMTIME,	/* 245 */
-	OP_FTATIME,	/* 246 */
-	OP_FTCTIME,	/* 247 */
-	OP_FTSOCK,	/* 248 */
-	OP_FTCHR,	/* 249 */
-	OP_FTBLK,	/* 250 */
-	OP_FTFILE,	/* 251 */
-	OP_FTDIR,	/* 252 */
-	OP_FTPIPE,	/* 253 */
-	OP_FTLINK,	/* 254 */
-	OP_FTSUID,	/* 255 */
-	OP_FTSGID,	/* 256 */
-	OP_FTSVTX,	/* 257 */
-	OP_FTTTY,	/* 258 */
-	OP_FTTEXT,	/* 259 */
-	OP_FTBINARY,	/* 260 */
-	OP_CHDIR,	/* 261 */
-	OP_CHOWN,	/* 262 */
-	OP_CHROOT,	/* 263 */
-	OP_UNLINK,	/* 264 */
-	OP_CHMOD,	/* 265 */
-	OP_UTIME,	/* 266 */
-	OP_RENAME,	/* 267 */
-	OP_LINK,	/* 268 */
-	OP_SYMLINK,	/* 269 */
-	OP_READLINK,	/* 270 */
-	OP_MKDIR,	/* 271 */
-	OP_RMDIR,	/* 272 */
-	OP_OPEN_DIR,	/* 273 */
-	OP_READDIR,	/* 274 */
-	OP_TELLDIR,	/* 275 */
-	OP_SEEKDIR,	/* 276 */
-	OP_REWINDDIR,	/* 277 */
-	OP_CLOSEDIR,	/* 278 */
-	OP_FORK,	/* 279 */
-	OP_WAIT,	/* 280 */
-	OP_WAITPID,	/* 281 */
-	OP_SYSTEM,	/* 282 */
-	OP_EXEC,	/* 283 */
-	OP_KILL,	/* 284 */
-	OP_GETPPID,	/* 285 */
-	OP_GETPGRP,	/* 286 */
-	OP_SETPGRP,	/* 287 */
-	OP_GETPRIORITY,	/* 288 */
-	OP_SETPRIORITY,	/* 289 */
-	OP_TIME,	/* 290 */
-	OP_TMS,		/* 291 */
-	OP_LOCALTIME,	/* 292 */
-	OP_GMTIME,	/* 293 */
-	OP_ALARM,	/* 294 */
-	OP_SLEEP,	/* 295 */
-	OP_SHMGET,	/* 296 */
-	OP_SHMCTL,	/* 297 */
-	OP_SHMREAD,	/* 298 */
-	OP_SHMWRITE,	/* 299 */
-	OP_MSGGET,	/* 300 */
-	OP_MSGCTL,	/* 301 */
-	OP_MSGSND,	/* 302 */
-	OP_MSGRCV,	/* 303 */
-	OP_SEMGET,	/* 304 */
-	OP_SEMCTL,	/* 305 */
-	OP_SEMOP,	/* 306 */
-	OP_REQUIRE,	/* 307 */
-	OP_DOFILE,	/* 308 */
-	OP_ENTEREVAL,	/* 309 */
-	OP_LEAVEEVAL,	/* 310 */
-	OP_ENTERTRY,	/* 311 */
-	OP_LEAVETRY,	/* 312 */
-	OP_GHBYNAME,	/* 313 */
-	OP_GHBYADDR,	/* 314 */
-	OP_GHOSTENT,	/* 315 */
-	OP_GNBYNAME,	/* 316 */
-	OP_GNBYADDR,	/* 317 */
-	OP_GNETENT,	/* 318 */
-	OP_GPBYNAME,	/* 319 */
-	OP_GPBYNUMBER,	/* 320 */
-	OP_GPROTOENT,	/* 321 */
-	OP_GSBYNAME,	/* 322 */
-	OP_GSBYPORT,	/* 323 */
-	OP_GSERVENT,	/* 324 */
-	OP_SHOSTENT,	/* 325 */
-	OP_SNETENT,	/* 326 */
-	OP_SPROTOENT,	/* 327 */
-	OP_SSERVENT,	/* 328 */
-	OP_EHOSTENT,	/* 329 */
-	OP_ENETENT,	/* 330 */
-	OP_EPROTOENT,	/* 331 */
-	OP_ESERVENT,	/* 332 */
-	OP_GPWNAM,	/* 333 */
-	OP_GPWUID,	/* 334 */
-	OP_GPWENT,	/* 335 */
-	OP_SPWENT,	/* 336 */
-	OP_EPWENT,	/* 337 */
-	OP_GGRNAM,	/* 338 */
-	OP_GGRGID,	/* 339 */
-	OP_GGRENT,	/* 340 */
-	OP_SGRENT,	/* 341 */
-	OP_EGRENT,	/* 342 */
-	OP_GETLOGIN,	/* 343 */
-	OP_SYSCALL,	/* 344 */
-	OP_LOCK,	/* 345 */
-	OP_THREADSV,	/* 346 */
+	OP_QR,		/* 32 */
+	OP_SUBST,	/* 33 */
+	OP_SUBSTCONT,	/* 34 */
+	OP_TRANS,	/* 35 */
+	OP_SASSIGN,	/* 36 */
+	OP_AASSIGN,	/* 37 */
+	OP_CHOP,	/* 38 */
+	OP_SCHOP,	/* 39 */
+	OP_CHOMP,	/* 40 */
+	OP_SCHOMP,	/* 41 */
+	OP_DEFINED,	/* 42 */
+	OP_UNDEF,	/* 43 */
+	OP_STUDY,	/* 44 */
+	OP_POS,		/* 45 */
+	OP_PREINC,	/* 46 */
+	OP_I_PREINC,	/* 47 */
+	OP_PREDEC,	/* 48 */
+	OP_I_PREDEC,	/* 49 */
+	OP_POSTINC,	/* 50 */
+	OP_I_POSTINC,	/* 51 */
+	OP_POSTDEC,	/* 52 */
+	OP_I_POSTDEC,	/* 53 */
+	OP_POW,		/* 54 */
+	OP_MULTIPLY,	/* 55 */
+	OP_I_MULTIPLY,	/* 56 */
+	OP_DIVIDE,	/* 57 */
+	OP_I_DIVIDE,	/* 58 */
+	OP_MODULO,	/* 59 */
+	OP_I_MODULO,	/* 60 */
+	OP_REPEAT,	/* 61 */
+	OP_ADD,		/* 62 */
+	OP_I_ADD,	/* 63 */
+	OP_SUBTRACT,	/* 64 */
+	OP_I_SUBTRACT,	/* 65 */
+	OP_CONCAT,	/* 66 */
+	OP_STRINGIFY,	/* 67 */
+	OP_LEFT_SHIFT,	/* 68 */
+	OP_RIGHT_SHIFT,	/* 69 */
+	OP_LT,		/* 70 */
+	OP_I_LT,	/* 71 */
+	OP_GT,		/* 72 */
+	OP_I_GT,	/* 73 */
+	OP_LE,		/* 74 */
+	OP_I_LE,	/* 75 */
+	OP_GE,		/* 76 */
+	OP_I_GE,	/* 77 */
+	OP_EQ,		/* 78 */
+	OP_I_EQ,	/* 79 */
+	OP_NE,		/* 80 */
+	OP_I_NE,	/* 81 */
+	OP_NCMP,	/* 82 */
+	OP_I_NCMP,	/* 83 */
+	OP_SLT,		/* 84 */
+	OP_SGT,		/* 85 */
+	OP_SLE,		/* 86 */
+	OP_SGE,		/* 87 */
+	OP_SEQ,		/* 88 */
+	OP_SNE,		/* 89 */
+	OP_SCMP,	/* 90 */
+	OP_BIT_AND,	/* 91 */
+	OP_BIT_XOR,	/* 92 */
+	OP_BIT_OR,	/* 93 */
+	OP_NEGATE,	/* 94 */
+	OP_I_NEGATE,	/* 95 */
+	OP_NOT,		/* 96 */
+	OP_COMPLEMENT,	/* 97 */
+	OP_ATAN2,	/* 98 */
+	OP_SIN,		/* 99 */
+	OP_COS,		/* 100 */
+	OP_RAND,	/* 101 */
+	OP_SRAND,	/* 102 */
+	OP_EXP,		/* 103 */
+	OP_LOG,		/* 104 */
+	OP_SQRT,	/* 105 */
+	OP_INT,		/* 106 */
+	OP_HEX,		/* 107 */
+	OP_OCT,		/* 108 */
+	OP_ABS,		/* 109 */
+	OP_LENGTH,	/* 110 */
+	OP_SUBSTR,	/* 111 */
+	OP_VEC,		/* 112 */
+	OP_INDEX,	/* 113 */
+	OP_RINDEX,	/* 114 */
+	OP_SPRINTF,	/* 115 */
+	OP_FORMLINE,	/* 116 */
+	OP_ORD,		/* 117 */
+	OP_CHR,		/* 118 */
+	OP_CRYPT,	/* 119 */
+	OP_UCFIRST,	/* 120 */
+	OP_LCFIRST,	/* 121 */
+	OP_UC,		/* 122 */
+	OP_LC,		/* 123 */
+	OP_QUOTEMETA,	/* 124 */
+	OP_RV2AV,	/* 125 */
+	OP_AELEMFAST,	/* 126 */
+	OP_AELEM,	/* 127 */
+	OP_ASLICE,	/* 128 */
+	OP_EACH,	/* 129 */
+	OP_VALUES,	/* 130 */
+	OP_KEYS,	/* 131 */
+	OP_DELETE,	/* 132 */
+	OP_EXISTS,	/* 133 */
+	OP_RV2HV,	/* 134 */
+	OP_HELEM,	/* 135 */
+	OP_HSLICE,	/* 136 */
+	OP_UNPACK,	/* 137 */
+	OP_PACK,	/* 138 */
+	OP_SPLIT,	/* 139 */
+	OP_JOIN,	/* 140 */
+	OP_LIST,	/* 141 */
+	OP_LSLICE,	/* 142 */
+	OP_ANONLIST,	/* 143 */
+	OP_ANONHASH,	/* 144 */
+	OP_SPLICE,	/* 145 */
+	OP_PUSH,	/* 146 */
+	OP_POP,		/* 147 */
+	OP_SHIFT,	/* 148 */
+	OP_UNSHIFT,	/* 149 */
+	OP_SORT,	/* 150 */
+	OP_REVERSE,	/* 151 */
+	OP_GREPSTART,	/* 152 */
+	OP_GREPWHILE,	/* 153 */
+	OP_MAPSTART,	/* 154 */
+	OP_MAPWHILE,	/* 155 */
+	OP_RANGE,	/* 156 */
+	OP_FLIP,	/* 157 */
+	OP_FLOP,	/* 158 */
+	OP_AND,		/* 159 */
+	OP_OR,		/* 160 */
+	OP_XOR,		/* 161 */
+	OP_COND_EXPR,	/* 162 */
+	OP_ANDASSIGN,	/* 163 */
+	OP_ORASSIGN,	/* 164 */
+	OP_METHOD,	/* 165 */
+	OP_ENTERSUB,	/* 166 */
+	OP_LEAVESUB,	/* 167 */
+	OP_CALLER,	/* 168 */
+	OP_WARN,	/* 169 */
+	OP_DIE,		/* 170 */
+	OP_RESET,	/* 171 */
+	OP_LINESEQ,	/* 172 */
+	OP_NEXTSTATE,	/* 173 */
+	OP_DBSTATE,	/* 174 */
+	OP_UNSTACK,	/* 175 */
+	OP_ENTER,	/* 176 */
+	OP_LEAVE,	/* 177 */
+	OP_SCOPE,	/* 178 */
+	OP_ENTERITER,	/* 179 */
+	OP_ITER,	/* 180 */
+	OP_ENTERLOOP,	/* 181 */
+	OP_LEAVELOOP,	/* 182 */
+	OP_RETURN,	/* 183 */
+	OP_LAST,	/* 184 */
+	OP_NEXT,	/* 185 */
+	OP_REDO,	/* 186 */
+	OP_DUMP,	/* 187 */
+	OP_GOTO,	/* 188 */
+	OP_EXIT,	/* 189 */
+	OP_OPEN,	/* 190 */
+	OP_CLOSE,	/* 191 */
+	OP_PIPE_OP,	/* 192 */
+	OP_FILENO,	/* 193 */
+	OP_UMASK,	/* 194 */
+	OP_BINMODE,	/* 195 */
+	OP_TIE,		/* 196 */
+	OP_UNTIE,	/* 197 */
+	OP_TIED,	/* 198 */
+	OP_DBMOPEN,	/* 199 */
+	OP_DBMCLOSE,	/* 200 */
+	OP_SSELECT,	/* 201 */
+	OP_SELECT,	/* 202 */
+	OP_GETC,	/* 203 */
+	OP_READ,	/* 204 */
+	OP_ENTERWRITE,	/* 205 */
+	OP_LEAVEWRITE,	/* 206 */
+	OP_PRTF,	/* 207 */
+	OP_PRINT,	/* 208 */
+	OP_SYSOPEN,	/* 209 */
+	OP_SYSSEEK,	/* 210 */
+	OP_SYSREAD,	/* 211 */
+	OP_SYSWRITE,	/* 212 */
+	OP_SEND,	/* 213 */
+	OP_RECV,	/* 214 */
+	OP_EOF,		/* 215 */
+	OP_TELL,	/* 216 */
+	OP_SEEK,	/* 217 */
+	OP_TRUNCATE,	/* 218 */
+	OP_FCNTL,	/* 219 */
+	OP_IOCTL,	/* 220 */
+	OP_FLOCK,	/* 221 */
+	OP_SOCKET,	/* 222 */
+	OP_SOCKPAIR,	/* 223 */
+	OP_BIND,	/* 224 */
+	OP_CONNECT,	/* 225 */
+	OP_LISTEN,	/* 226 */
+	OP_ACCEPT,	/* 227 */
+	OP_SHUTDOWN,	/* 228 */
+	OP_GSOCKOPT,	/* 229 */
+	OP_SSOCKOPT,	/* 230 */
+	OP_GETSOCKNAME,	/* 231 */
+	OP_GETPEERNAME,	/* 232 */
+	OP_LSTAT,	/* 233 */
+	OP_STAT,	/* 234 */
+	OP_FTRREAD,	/* 235 */
+	OP_FTRWRITE,	/* 236 */
+	OP_FTREXEC,	/* 237 */
+	OP_FTEREAD,	/* 238 */
+	OP_FTEWRITE,	/* 239 */
+	OP_FTEEXEC,	/* 240 */
+	OP_FTIS,	/* 241 */
+	OP_FTEOWNED,	/* 242 */
+	OP_FTROWNED,	/* 243 */
+	OP_FTZERO,	/* 244 */
+	OP_FTSIZE,	/* 245 */
+	OP_FTMTIME,	/* 246 */
+	OP_FTATIME,	/* 247 */
+	OP_FTCTIME,	/* 248 */
+	OP_FTSOCK,	/* 249 */
+	OP_FTCHR,	/* 250 */
+	OP_FTBLK,	/* 251 */
+	OP_FTFILE,	/* 252 */
+	OP_FTDIR,	/* 253 */
+	OP_FTPIPE,	/* 254 */
+	OP_FTLINK,	/* 255 */
+	OP_FTSUID,	/* 256 */
+	OP_FTSGID,	/* 257 */
+	OP_FTSVTX,	/* 258 */
+	OP_FTTTY,	/* 259 */
+	OP_FTTEXT,	/* 260 */
+	OP_FTBINARY,	/* 261 */
+	OP_CHDIR,	/* 262 */
+	OP_CHOWN,	/* 263 */
+	OP_CHROOT,	/* 264 */
+	OP_UNLINK,	/* 265 */
+	OP_CHMOD,	/* 266 */
+	OP_UTIME,	/* 267 */
+	OP_RENAME,	/* 268 */
+	OP_LINK,	/* 269 */
+	OP_SYMLINK,	/* 270 */
+	OP_READLINK,	/* 271 */
+	OP_MKDIR,	/* 272 */
+	OP_RMDIR,	/* 273 */
+	OP_OPEN_DIR,	/* 274 */
+	OP_READDIR,	/* 275 */
+	OP_TELLDIR,	/* 276 */
+	OP_SEEKDIR,	/* 277 */
+	OP_REWINDDIR,	/* 278 */
+	OP_CLOSEDIR,	/* 279 */
+	OP_FORK,	/* 280 */
+	OP_WAIT,	/* 281 */
+	OP_WAITPID,	/* 282 */
+	OP_SYSTEM,	/* 283 */
+	OP_EXEC,	/* 284 */
+	OP_KILL,	/* 285 */
+	OP_GETPPID,	/* 286 */
+	OP_GETPGRP,	/* 287 */
+	OP_SETPGRP,	/* 288 */
+	OP_GETPRIORITY,	/* 289 */
+	OP_SETPRIORITY,	/* 290 */
+	OP_TIME,	/* 291 */
+	OP_TMS,		/* 292 */
+	OP_LOCALTIME,	/* 293 */
+	OP_GMTIME,	/* 294 */
+	OP_ALARM,	/* 295 */
+	OP_SLEEP,	/* 296 */
+	OP_SHMGET,	/* 297 */
+	OP_SHMCTL,	/* 298 */
+	OP_SHMREAD,	/* 299 */
+	OP_SHMWRITE,	/* 300 */
+	OP_MSGGET,	/* 301 */
+	OP_MSGCTL,	/* 302 */
+	OP_MSGSND,	/* 303 */
+	OP_MSGRCV,	/* 304 */
+	OP_SEMGET,	/* 305 */
+	OP_SEMCTL,	/* 306 */
+	OP_SEMOP,	/* 307 */
+	OP_REQUIRE,	/* 308 */
+	OP_DOFILE,	/* 309 */
+	OP_ENTEREVAL,	/* 310 */
+	OP_LEAVEEVAL,	/* 311 */
+	OP_ENTERTRY,	/* 312 */
+	OP_LEAVETRY,	/* 313 */
+	OP_GHBYNAME,	/* 314 */
+	OP_GHBYADDR,	/* 315 */
+	OP_GHOSTENT,	/* 316 */
+	OP_GNBYNAME,	/* 317 */
+	OP_GNBYADDR,	/* 318 */
+	OP_GNETENT,	/* 319 */
+	OP_GPBYNAME,	/* 320 */
+	OP_GPBYNUMBER,	/* 321 */
+	OP_GPROTOENT,	/* 322 */
+	OP_GSBYNAME,	/* 323 */
+	OP_GSBYPORT,	/* 324 */
+	OP_GSERVENT,	/* 325 */
+	OP_SHOSTENT,	/* 326 */
+	OP_SNETENT,	/* 327 */
+	OP_SPROTOENT,	/* 328 */
+	OP_SSERVENT,	/* 329 */
+	OP_EHOSTENT,	/* 330 */
+	OP_ENETENT,	/* 331 */
+	OP_EPROTOENT,	/* 332 */
+	OP_ESERVENT,	/* 333 */
+	OP_GPWNAM,	/* 334 */
+	OP_GPWUID,	/* 335 */
+	OP_GPWENT,	/* 336 */
+	OP_SPWENT,	/* 337 */
+	OP_EPWENT,	/* 338 */
+	OP_GGRNAM,	/* 339 */
+	OP_GGRGID,	/* 340 */
+	OP_GGRENT,	/* 341 */
+	OP_SGRENT,	/* 342 */
+	OP_EGRENT,	/* 343 */
+	OP_GETLOGIN,	/* 344 */
+	OP_SYSCALL,	/* 345 */
+	OP_LOCK,	/* 346 */
+	OP_THREADSV,	/* 347 */
 	OP_max		
 } opcode;
 
-#define MAXO 347
+#define MAXO 348
 
 #ifndef DOINIT
 EXT char *op_name[];
@@ -392,6 +393,7 @@ EXT char *op_name[] = {
 	"regcreset",
 	"regcomp",
 	"match",
+	"qr",
 	"subst",
 	"substcont",
 	"trans",
@@ -746,6 +748,7 @@ EXT char *op_desc[] = {
 	"regexp reset interpolation flag",
 	"regexp compilation",
 	"pattern match",
+	"pattern quote",
 	"substitution",
 	"substitution cont",
 	"character translation",
@@ -1132,6 +1135,7 @@ OP *	pp_regcmaybe	_((ARGSproto));
 OP *	pp_regcreset	_((ARGSproto));
 OP *	pp_regcomp	_((ARGSproto));
 OP *	pp_match	_((ARGSproto));
+OP *	pp_qr		_((ARGSproto));
 OP *	pp_subst	_((ARGSproto));
 OP *	pp_substcont	_((ARGSproto));
 OP *	pp_trans	_((ARGSproto));
@@ -1488,6 +1492,7 @@ EXT OP * (CPERLscope(*ppaddr)[])(ARGSproto) = {
 	pp_regcreset,
 	pp_regcomp,
 	pp_match,
+	pp_qr,
 	pp_subst,
 	pp_substcont,
 	pp_trans,
@@ -1844,6 +1849,7 @@ EXT OP * (CPERLscope(*check)[]) _((OP *op)) = {
 	ck_fun,		/* regcreset */
 	ck_null,	/* regcomp */
 	ck_match,	/* match */
+	ck_match,	/* qr */
 	ck_null,	/* subst */
 	ck_null,	/* substcont */
 	ck_null,	/* trans */
@@ -2180,7 +2186,7 @@ EXT U32 opargs[] = {
 	0x00000040,	/* padav */
 	0x00000040,	/* padhv */
 	0x00000040,	/* padany */
-	0x00000600,	/* pushre */
+	0x00000640,	/* pushre */
 	0x00000144,	/* rv2gv */
 	0x00000144,	/* rv2sv */
 	0x00000114,	/* av2arylen */
@@ -2199,6 +2205,7 @@ EXT U32 opargs[] = {
 	0x00001104,	/* regcreset */
 	0x00001304,	/* regcomp */
 	0x00000640,	/* match */
+	0x00000004,	/* qr */
 	0x00001654,	/* subst */
 	0x00000354,	/* substcont */
 	0x00001914,	/* trans */
